@@ -1,6 +1,6 @@
-from .write_utils import DocWriteUtils
+from .chunk_doc_utils import ChunkDocUtils
 
-class DocUtils(DocWriteUtils):
+class DocUtils(ChunkDocUtils):
     """Class for all document utilities. 
     Primarily should be used as a mixin for future functions
     but can be a standalone.
